@@ -1,17 +1,21 @@
 import datetime
 import functools
+import inspect
 import os
+import random
 import sqlite3
+import string
 import sys
 import time
 from functools import wraps
+from typing import Any
 
 import aredis
 import pymysql
 
 ENGINE_SQLITE = 'sqlite'
 ENGINE_MYSQL = 'mysql'
-ENGINE_REDIS = 'redis'
+ENGINE_REDIS = 'async_redis'
 danger_sig = ['--', '-+', '#']
 start_time = int(time.time())
 ENGINE_DICT = {
@@ -35,23 +39,28 @@ def get_filename():
         fn = '%s\\.anduin\\%s-%s.log' % (os.path.expanduser('~'), sys.argv[0].split('\\')[-1], start_time)
     return fn
 
-
 fn = get_filename()
-# if sys.platform != 'win32':
-try:
-    os.mkdir('%s/.anduin' % os.path.expanduser('~'))
-except Exception as e:
-    print(str(e))
-print('anduin调用日志保存在%s' % get_filename())
-# else:
-#     print('该操作系统为windows系统，暂时无法保存日志')
+if sys.platform != 'win32':
+    try:
+        os.mkdir('%s/.anduin' % os.path.expanduser('~'))
+    except Exception as e:
+        print(str(e))
+    print('系统内核为',sys.platform,'本插件调用日志保存在%s' % get_filename())
+else:
+    print('windows下不支持持久化日志，请自行控制台生产')
 fh = open(fn, 'a')
 
 
+if sys.platform != 'win32':
+    write_log = True
+else:
+    write_log = False
+
+
 def dbg(*args):
     res = ['[%s Anduin Engine]' % time_to_str(int(time.time()))] + list(args)
     print(*res)
-    if sys.platform != 'win32':
+    if write_log:
         for i in res:
             fh.write(str(i) + ' ')
         fh.write('\n')
@@ -111,5 +120,12 @@ def async_decorators(method):
 
     return wrapper
 
-def get_obj_name(obj):
-    return obj.__name__
\ No newline at end of file
+def get_obj_name(obj: Any) -> str:
+    """获取对象的名称"""
+    if inspect.isfunction(obj) or inspect.isclass(obj):
+        return obj.__name__
+    return obj.__class__.__name__
+
+def create_rand_string(length=16):
+    ran_str = ''.join(random.sample(string.ascii_letters + string.digits, length))
+    return ran_str
\ No newline at end of file
